<?php
/*
 * SZPhotoGallery :: Handler for images in mySQL. Version 1.3
 * Copyright (C) 2002-2003 Andreas Norman. All rights reserved.
 * 
 * THIS SOFTWARE IS PROVIDED 'AS IS' AND ANY EXPRESS OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 * 
 * This software is FREE FOR NON-COMMERCIAL USE, provided the following 
 * conditions are met:
 * 
 * The user must assume the entire risk of using this program.
 * 
 * You are hereby granted a license to to use and distribute this 
 * program in its original unmodified form and in the original 
 * distribution package. You can make as many copies as you want, 
 * and distribute it via electronic means. There is no fee for
 * any of the above.
 * 
 * You are specifically prohibited from charging, or requesting
 * donations, for any such copies, however made; and from distributing
 * the software and/or documentation with other products (commercial or
 * otherwise) without prior written permission.
 * 
 * * * * * * * * * * * * * * * * * * * * *
 * Requirements: MySQLHandler.class.php  *
 *               ImageHandler.class.php  *
 *                     SZMail.class.php  *
 * * * * * * * * * * * * * * * * * * * * *
 */
class SZPhotoGallery {  
  
  var $TABLES = Array (
                  'settings'      =>  'szphotogallery',
                  'photogallery'  =>  'photogallery',
                  'postcards'  =>  'photo_postcards',
                  'categories'    =>  'photo_categories'
                  );
  var $TEMPLATES = Array (
                  'body'  =>  'templates/gallery.inc',
                  'details'  =>  'templates/gallery.details.inc',
                  'ecard' =>  'templates/ecard.inc',
                  'navs'  =>  'templates/gallery.end.inc'
                  );
  var $ImageHandler;
  var $SZBBCodes;
  var $sql;
  var $classname;
  var $PER_PAGE = 25;
  var $ERROR_MSG='';
  var $SZMail;
  
  function SZPhotoGallery($sql, $ImageHandler, $SZBBCodes, $SZMail = false) {
    $this->sql = $sql;
    $this->SZBBCodes = $SZBBCodes;
    $this->ImageHandler = $ImageHandler;
    $this->SZMail = $SZMail;
  }
  
  function getPostcardList() {
    $data = $this->sql->Select("SELECT id, headline, sender_email, receiver_email, image_id, viewed FROM ".$this->TABLES['postcards']." ORDER BY date ASC");
    $len = count($data);
    if ($len < 1) {
      $str = '
        <tr>
          <td class="lightbg" colspan="6">No e-cards found...</td>
        </tr>
      ';
    } else {
      $str ='
          <tr>
            <td class="icon_darkbg" width="1%"></td>
            <td class="listheader">Headline</td>
            <td class="listheader" nowrap>Sender Email</td>
            <td class="listheader" nowrap>Receiver Email</td>
            <td class="listheader" nowrap>Viewed</td>
            <td class="icon_darkbg" width="1%"></td>
          </tr>
      ';
    }
    for ($i=0; $i< $len; $i++) {
      if ($this->classname == 'lightbg') {
        $this->classname = 'darkbg';
      } else {
        $this->classname = 'lightbg';
      }
      $check_image = $data[$i]['viewed'] > 0 ? 'check_on.gif' : 'check_off.gif';
      $str .='
        <tr>
          <td class="icon_'.$this->classname.'"><a href="photo.ecard.remove.php?ID='.$data[$i]['id'].'"><img src="images/icons/remove.gif" align="absmiddle" alt="" border="0"></a></td>
          <td class="'.$this->classname.'">'.stripslashes($data[$i]['headline']).'</td>
          <td class="'.$this->classname.'">'.stripslashes($data[$i]['sender_email']).'</td>
          <td class="'.$this->classname.'">'.stripslashes($data[$i]['receiver_email']).'</td>
          <td align="center" class="'.$this->classname.'" ><img src="images/icons/'.$check_image.'" alt="" border="0"></td>
          <td class="'.$this->classname.'"><a target="_blank" href="photogallery.view.php?ID='.$data[$i]['image_id'].'"><img src="images/icons/view.gif" alt="" width="19" height="19" border="0"></a></td>
        </tr>
      ';
    }
    return $str;
  }

  function createPostcard($image_id, $name, $headline, $body, $receiver_email, $sender_email) {
    if (!empty($image_id) && !empty($headline) && !empty($body) && !$this->isValidEmail($receiver_email) && !$this->isValidEmail($sender_email)) {
      if ($ID = $this->sql->Insert("INSERT INTO ".$this->TABLES['postcards']." (date, image_id, headline, body, sender_email, receiver_email, hashkey, name) VALUES (NOW()+1, ".$image_id.", '".addslashes($headline)."', '".addslashes($body)."', '".addslashes($sender_email)."', '".addslashes($receiver_email)."', '".md5(date("YmdHi").$sender_email.$receiver_email)."', '".addslashes($name)."')")) {
        if ($this->sendPostcard($ID)) {
          return true;
        } else {
          return false;
        }
      } else {
        $this->appendErrorMessage('Unable to add entry. Probably duplicate entry');
        return false;
      }
    } else {
      $this->appendErrorMessage('You must fill out all required fields!');
      return false;
    }
  }
  
  function getPostcardByHashkey($hashkey) {
    $this->removeExpiredPostcards();
    $this->sql->Update("UPDATE ".$this->TABLES['postcards']." SET viewed = 1 WHERE hashkey = '".$hashkey."'");
    return $this->sql->Select("SELECT * FROM ".$this->TABLES['postcards']." WHERE hashkey = '".$hashkey."'");
  }
  
  function getPostcard($ID) {
    return $this->sql->Select("SELECT * FROM ".$this->TABLES['postcards']." WHERE id = $ID");
  }
  
  function removeExpiredPostcards() {
    $data = $this->getPreferences();
    $date = date("YmdHis") + date("H",  mktime($data[0]['postcard_lifetime'],0,0,0,0,0));
    $this->sql->Delete("DELETE FROM ".$this->TABLES['postcards']." WHERE date < ".$date);
  }
  
  function sendPostcard($ID) {
    $pc_data = $this->getPostcard($ID);
    $data = $this->getPreferences();
    $headline = str_replace('[NAME]', stripslashes($pc_data[0]['name']), $data[0]['postcard_subject']);
    $body = $data[0]['postcard_body'];
    $body = str_replace('[NAME]', stripslashes($pc_data[0]['name']), $body);
    $body = str_replace('[SENDER_EMAIL]', stripslashes($pc_data[0]['sender_email']), $body);
    $body = str_replace('[LINK]', stripslashes($data[0]['site_url']).'/postcard.view.php?hashkey='.$pc_data[0]['hashkey'], $body);
    $body_temp = str_replace('[THUMB_WIDTH]', $data[$i]['twidth'], $body_temp);

    if (mail(stripslashes($pc_data[0]['receiver_email']), addslashes($headline), addslashes($body),"From: ".stripslashes($data[0]['postcard_senderemail']))) {
      return true;
    } else {
      return false;
    }
  }
  
  function removePostcard($ID) {
    $this->sql->Delete("DELETE FROM ".$this->TABLES['postcards']." WHERE id = $ID");
    return true;
  }
  
  function add($name, $description, $category_id, $image, $image_type, $thumb, $thumb_type, $ecard) {
    $prefs = $this->getPreferences();
    $this->ImageHandler->setThumbnailWidth($prefs[0]['thumb_width']);
    $this->ImageHandler->setMaxHeight($prefs[0]['max_height']);
    $ecard = $ecard==='on'?1:0;
    if (!empty($name)) {
      if (filesize($thumb) > 0) {
        if ($image_id = $this->ImageHandler->UploadImage($image, $image_type, false)) {
          if ($this->sql->Insert("INSERT INTO ".$this->TABLES['photogallery']." (image_id, date, name, description, category_id, ecard) VALUES (".$image_id[0].", NOW()+1, '".addslashes($name)."', '".htmlentities(addslashes($description))."', ".$category_id.", ".$ecard.")")) {
            $this->ImageHandler->UpdateThumbnail($image_id[0], $thumb, $thumb_type);
            return true;
          } else {
            $this->appendErrorMessage('Unable to add photo');
            return false;
          }
        } else {
          $this->appendErrorMessage($this->ImageHandler->ERROR_MSG);
          return false;
        }
      } else {
        if ($image_id = $this->ImageHandler->UploadImage($image, $image_type, true)) {
          if ($this->sql->Insert("INSERT INTO ".$this->TABLES['photogallery']." (image_id, date, name, description, category_id, ecard) VALUES (".$image_id[0].", NOW()+1, '".addslashes($name)."', '".htmlentities(addslashes($description))."', ".$category_id.", ".$ecard.")")) {
            return true;
          } else {
            $this->appendErrorMessage('Unable to add photo');
            return false;
          }
        } else {
          $this->appendErrorMessage($this->ImageHandler->ERROR_MSG);
          return false;
        }
      }
    } else {
      $this->appendErrorMessage('You need to specify a name');
      return false;
    }
  }
  
  function update($image_id, $name, $description, $category_id, $image, $image_type, $thumb, $thumb_type, $update_thumbnail, $ecard) {
    $prefs = $this->getPreferences();
    $this->ImageHandler->setThumbnailWidth($prefs[0]['thumb_width']);
    $this->ImageHandler->setMaxHeight($prefs[0]['max_height']);
    $ecard = $ecard==='on'?1:0;
    $update_thumbnail = $update_thumbnail==='on'?1:0;
    if (!empty($name)) {
      if (filesize($thumb) > 0) {
        if (filesize($image) > 0) {
          $this->ImageHandler->UploadImage($image, $image_type, false, $image_id);
          $this->ImageHandler->UpdateThumbnail($image_id, $thumb, $thumb_type);
        } else {
          $this->ImageHandler->UpdateThumbnail($image_id, $thumb, $thumb_type);
        }
      } else {
        if (filesize($image) > 0) {
          if ($update_thumbnail > 0) {
            $this->ImageHandler->UploadImage($image, $image_type, true, $image_id);
          } else {
            $this->ImageHandler->UploadImage($image, $image_type, false, $image_id);
          }
        }
      }
      $this->sql->Update("UPDATE ".$this->TABLES['photogallery']." SET ecard = ".$ecard.", name = '".addslashes($name)."', description = '".addslashes($description)."', category_id = ".$category_id." WHERE image_id = $image_id");
      return true;
    } else {
      $this->appendErrorMessage('You need to specify a name');
      return false;
    }
  }
    
  function search($keywords, $andor, $category_id) {
    $keyarray = explode(" ", $keywords);
    if ($category_id > 0) {
      $searchstr = "SELECT id FROM ".$this->TABLES['photogallery']." WHERE category_id = ".$category_id." AND";
    } else {
      $searchstr = "SELECT id FROM ".$this->TABLES['photogallery']." WHERE";
    }
    $searchstr .= " (";
    for ($i=0;$i<count($keyarray);$i++) {
      #$keyarray[$i] = str_replace("*", "%", $keyarray[$i]);
      $keyarray[$i] = "%".strtolower($keyarray[$i])."%";
      if (count($keyarray) > 1) {
        $searchstr .= "(LCASE(name) LIKE '".$keyarray[$i]."' OR LCASE(description) LIKE '".$keyarray[$i]."') ".$andor;
      } else {
        $searchstr .= "(LCASE(name) LIKE '".$keyarray[$i]."' OR LCASE(description) LIKE '".$keyarray[$i]."')";
      }
    }
    if (count($keyarray) > 1) {
      $searchstr = substr($searchstr, 0, (strlen($searchstr)-3));
    }
    $searchstr .= ")";
    $data = $this->sql->Select($searchstr);
    for ($i=0; $i<count($data); $i++) {
      $items[$i] = $data[$i]['id'];
    }
    return implode(",", $items);
  }
  
  function getPhotoInfo($image_id) {
    return $this->sql->Select("SELECT * FROM ".$this->TABLES['photogallery']." WHERE image_id = $image_id");
  }
  
  function getEntriesAmount() {
    $rows = $this->sql->Select("SELECT COUNT(*) as num FROM ".$this->TABLES['photogallery']."");
    return $rows[0]["num"];
  }
  
  function getPhotogalleryList($category_id, $page = false) {
    if ($category_id) {
      $sql_text = "SELECT i.file_size, i.width, i.height, i.extension, p.image_id, p.name, p.date FROM ".$this->TABLES['photogallery']." AS p, ".$this->ImageHandler->TABLES['db_images']." AS i WHERE i.id = p.image_id AND p.category_id = ".$category_id." ORDER BY p.date DESC,  p.name DESC";
    } else {
      $sql_text = "SELECT i.file_size, i.width, i.height, i.extension, p.image_id, p.name, p.date FROM ".$this->TABLES['photogallery']." AS p, ".$this->ImageHandler->TABLES['db_images']." AS i WHERE i.id = p.image_id ORDER BY p.date DESC, p.name DESC";
    }
    if (!$page) {  
      $page = 1;  
    } 
    $page_start = ($this->PER_PAGE * $page) - $this->PER_PAGE;  
    $num_pages = $this->getNumPages($this->getEntriesAmount());
    if (($page > $num_pages) || ($page < 0)) {  
      $page = 1;
    }
    $str='';
    $sql_text = $sql_text . " LIMIT ".$page_start.", ".$this->PER_PAGE."";
    $data = $this->sql->Select($sql_text);
    if ($page > 1)  { 
      $str .= '   <td class="icon_darkbg"><a href="?page='.($page - 1).'"><img src="images/icons/prev.gif" align="absmiddle" alt="" border="0"></a></td>'."\n";
    } else {
      $str .= '   <td class="icon_darkbg"><img src="images/icons/prev_na.gif" align="absmiddle" alt="" border="0"></td>'."\n";        
    }
    if ($page != $num_pages) {
      $str .= '   <td class="icon_darkbg"><a href="?page='.($page + 1).'"><img src="images/icons/next.gif" align="absmiddle" alt="" border="0"></a></td>'."\n";
    } else {
      $str .= '   <td class="icon_darkbg"><img src="images/icons/next_na.gif" align="absmiddle" alt="" border="0"></td>'."\n";
    }
    if (count($data) < 1) {
      $str = '
        <tr>
          <td class="lightbg" colspan="9">No photos found...</td>
        </tr>
      ';
    } else {
    $str .='
          <td class="listheader">Name</td>
          <td class="listheader">Date</td>
          <td class="listheader">Width</td>
          <td class="listheader">Height</td>
          <td class="listheader">Type</td>
          <td class="listheader">File Size</td>
          <td class="icon_darkbg"></td>
        </tr>
    ';
    }
    for ($i=0;$i<count($data);$i++) {
      if ($this->classname == 'lightbg') {
        $this->classname = 'darkbg';
      } else {
        $this->classname = 'lightbg';
      }
      $str .='
        <tr>
          <td class="icon_'.$this->classname.'"><a href="photo.remove.php?image_id='.$data[$i]['image_id'].'"><img src="images/icons/remove.gif" align="absmiddle" alt="" border="0"></a></td>
          <td class="icon_'.$this->classname.'"><a href="photo.edit.php?image_id='.$data[$i]['image_id'].'"><img src="images/icons/edit.gif" align="absmiddle" alt="" border="0"></a></td>
          <td class="'.$this->classname.'">'.stripslashes($data[$i]['name']).'</td>
          <td class="'.$this->classname.'">'.$this->FormatDate("Y-m-d H:i", $data[$i]['date']).'</td>
          <td class="'.$this->classname.'">'.$data[$i]['width'].'</td>
          <td class="'.$this->classname.'">'.$data[$i]['height'].'</td>
          <td align="center" class="'.$this->classname.'">'.strtoupper($data[$i]['extension']).'</td>
          <td align="center" class="'.$this->classname.'">'.round($data[$i]['file_size'] / 1024).'kb</td>
          <td class="icon_'.$this->classname.'"><a target="_blank" href="photogallery.view.php?ID='.$data[$i]['image_id'].'"><img src="images/icons/view.gif" alt="" width="19" height="19" border="0"></a></td>
        </tr>
          ';
    }
    return $str;
  }
  
  function getPhotoDetails($ID) {
    $prefs = $this->getPreferences();
    $data = $this->sql->Select("SELECT p.ecard, t.id AS thumb_id, i.file_size, i.width iwidth, i.height iheight, t.width twidth, t.height theight, p.image_id, p.name, p.date, p.description FROM ".$this->TABLES['photogallery']." AS p, ".$this->ImageHandler->TABLES['db_images']." AS i, ".$this->ImageHandler->TABLES['db_image_mapping']." AS m, ".$this->ImageHandler->TABLES['db_thumbs']." AS t WHERE t.id = m.thumb_id AND m.image_id = i.id AND i.id = p.image_id AND i.id = ".$ID);
    $body_str = file_get_contents($this->TEMPLATES['details']);
    $body_temp = $body_str;
    $body_temp = str_replace('[NAME]', stripslashes($data[0]['name']), $body_temp);
    $body_temp = str_replace('[DATE]', $this->FormatDate(stripslashes($prefs[0]['date_formatting']), $data[0]['date']), $body_temp);
    $body_temp = str_replace('[DESCRIPTION]', $this->SZBBCodes->addStyle(stripslashes($data[0]['description'])), $body_temp);
    $body_temp = str_replace('[IMAGE_ID]', $data[0]['image_id'], $body_temp);
    $body_temp = str_replace('[THUMBNAIL_ID]', $data[0]['thumb_id'], $body_temp);
    $body_temp = str_replace('[IMAGE_WIDTH]', $data[0]['iwidth'], $body_temp);
    $body_temp = str_replace('[IMAGE_HEIGHT]', $data[0]['iheight'], $body_temp);
    $body_temp = str_replace('[THUMB_WIDTH]', $data[0]['twidth'], $body_temp);
    $body_temp = str_replace('[THUMB_HEIGHT]', $data[0]['theight'], $body_temp);
    $body = $body_temp;
    return $body;
  }
    
  function getPhotoGallery($category_id, $page = false, $searchresult = false, $limit = false) {
    if ($searchresult) {
      $condition = "AND p.id IN (".$searchresult.")";
    } else {
      $condition = "";
    }
    if ($category_id) {
      $sql_text = "SELECT p.ecard, t.id AS thumb_id, i.file_size, i.width iwidth, i.height iheight, t.width twidth, t.height theight, p.image_id, p.name, p.date, p.description FROM ".$this->TABLES['photogallery']." AS p, ".$this->ImageHandler->TABLES['db_images']." AS i, ".$this->ImageHandler->TABLES['db_image_mapping']." AS m, ".$this->ImageHandler->TABLES['db_thumbs']." AS t WHERE t.id = m.thumb_id AND m.image_id = i.id AND i.id = p.image_id AND p.category_id = ".$category_id." ".$condition." ORDER BY p.date DESC, p.name DESC ";
    } else {
      $sql_text = "SELECT p.ecard, t.id AS thumb_id, i.file_size, i.width iwidth, i.height iheight, t.width twidth, t.height theight, p.image_id, p.name, p.date, p.description FROM ".$this->TABLES['photogallery']." AS p, ".$this->ImageHandler->TABLES['db_images']." AS i, ".$this->ImageHandler->TABLES['db_image_mapping']." AS m, ".$this->ImageHandler->TABLES['db_thumbs']." AS t WHERE t.id = m.thumb_id AND m.image_id = i.id AND i.id = p.image_id ".$condition." ORDER BY p.date DESC, p.name DESC ";
    }
    $prefs = $this->getPreferences();
    if (!$page) {  
      $page = 1;  
    } 
    $this->PER_PAGE = $prefs[0]['per_page'];
    $page_start = ($this->PER_PAGE * $page) - $this->PER_PAGE;  
    $num_pages = $this->getNumPages($this->getEntriesAmount());
    if (($page > $num_pages) || ($page < 0)) {  
      $page = 1;
    }
    $body='';
    if ($limit) {
      $sql_text = $sql_text . " LIMIT ".$page_start.", ".$limit;
    } else {
      $sql_text = $sql_text . " LIMIT ".$page_start.", ".$this->PER_PAGE."";
    }
    if ($data = $this->sql->Select($sql_text)) {
      $navs_str = file_get_contents($this->TEMPLATES['navs']);
      $body_str = file_get_contents($this->TEMPLATES['body']);
      for ($i=0;$i<count($data);$i++) {
        if ($data[$i]['ecard'] > 0) {
          $ecard = ' - <a href="photogallery.postcard.create.php?ID=[IMAGE_ID]">Send as postcard</a>';
        } else {
          $ecard = '';
        }
        $body_temp = $body_str;
        $body_temp = str_replace('[NAME]', stripslashes($data[$i]['name']).$ecard, $body_temp);
        $body_temp = str_replace('[DATE]', $this->FormatDate(stripslashes($prefs[0]['date_formatting']), $data[$i]['date']), $body_temp);
        $body_temp = str_replace('[DESCRIPTION]', $this->SZBBCodes->addStyle(stripslashes($data[$i]['description'])), $body_temp);
        $body_temp = str_replace('[IMAGE_ID]', $data[$i]['image_id'], $body_temp);
        $body_temp = str_replace('[THUMBNAIL_ID]', $data[$i]['thumb_id'], $body_temp);
        $body_temp = str_replace('[IMAGE_WIDTH]', $data[$i]['iwidth'], $body_temp);
        $body_temp = str_replace('[IMAGE_HEIGHT]', $data[$i]['iheight'], $body_temp);
        $body_temp = str_replace('[THUMB_WIDTH]', $data[$i]['twidth'], $body_temp);
        $body_temp = str_replace('[THUMB_HEIGHT]', $data[$i]['theight'], $body_temp);
        $body .= $body_temp;
      }
      if ($page > 1)  { 
        $navs_str = str_replace('[PREV_URL]', '<a href="?page='.($page - 1).'">', $navs_str);
        $navs_str = str_replace('[/PREV_URL]', '</a>', $navs_str);
        $navs_str = str_replace('[PREV_EXTENSION]', '', $navs_str);
      } else {
        $navs_str = str_replace('[PREV_URL]', '', $navs_str);
        $navs_str = str_replace('[/PREV_URL]', '', $navs_str);
        $navs_str = str_replace('[PREV_EXTENSION]', '_na', $navs_str);
      }
      if ($page != $num_pages) {
        $navs_str = str_replace('[NEXT_URL]', '<a href="?page='.($page + 1).'">', $navs_str);
        $navs_str = str_replace('[/NEXT_URL]', '</a>', $navs_str);
        $navs_str = str_replace('[NEXT_EXTENSION]', '', $navs_str);
      } else {
        $navs_str = str_replace('[NEXT_URL]', '', $navs_str);
        $navs_str = str_replace('[/NEXT_URL]', '', $navs_str);
        $navs_str = str_replace('[NEXT_EXTENSION]', '_na', $navs_str);
      }
      if ($num_pages > 1) {
        $linkpages='';
        for ($j=1; $j<$num_pages+1; $j++) {
          if ($page == $j) {
            $linkpages .= $j.' ';
          } else {
            $linkpages .= '<a href="?page='.$j.'">'.$j.'</a> ';
          }
        }
        $navs_str = str_replace('[NUMBERS]', $linkpages, $navs_str);
      } else {
        $navs_str = str_replace('[NUMBERS]', '', $navs_str);
      }
    } else {
      $body_str='';
      $navs_str='';
    }
    return $body.$navs_str;  
  }
  
  function getCategoryInfo($ID) {
    return $this->sql->Select("SELECT * FROM ".$this->TABLES['categories']." WHERE id = $ID");
  }
  
  function getCategorySelectList($selected = false, $onchange = false) {
    $data = $this->sql->Select("SELECT id, category FROM ".$this->TABLES['categories']." ORDER BY category ASC");
    if ($onchange) {
      $str = '<select name="category_id">';
      $str .= '<option value="0">--- All Categories ---</option>';
    } else {
      $str = '<select name="category_id">';
    }
    for ($i=0;$i < count($data);++$i) {
      if ($selected && $data[$i]['id'] == $selected) {
      	$str .= '<option value="'.$data[$i]['id'].'" selected>'.$data[$i]['category'].'</option>';
      } else {
      	$str .= '<option value="'.$data[$i]['id'].'">'.$data[$i]['category'].'</option>';
      }
    }
    $str .= '</select>';
    return $str;
  }
  
  function addCategory($category, $description) {
    if (!empty($category)) {
      if ($this->sql->Insert("INSERT INTO ".$this->TABLES['categories']." (category, description) VALUES ('".addslashes($category)."', '".addslashes(strip_tags($description))."')")) {
        return true;
      } else {
        return false;
      }
    } else {
      return false;
    }
  }
  
  function updateCategory($ID, $category, $description) {
    if (!empty($category)) {
      $this->sql->Update("UPDATE ".$this->TABLES['categories']." SET category = '".addslashes($category)."', description = '".addslashes(strip_tags($description))."' WHERE id = $ID");
      return true;
    } else {
      return false;
    }
  }
  
  function removeCategory($ID) {
    $this->sql->Delete("DELETE FROM ".$this->TABLES['categories']." WHERE id = $ID");
    return true;
  }
  
  function getCategoryList() {
    $data = $this->sql->Select("SELECT id, category FROM ".$this->TABLES['categories']." ORDER BY category ASC");
    $len = count($data);
    if ($len < 1) {
      $str = '
        <tr>
          <td class="lightbg" colspan="3">No categories found...</td>
        </tr>
      ';
    } else {
      $str ='
          <tr>
            <td class="icon_darkbg" colspan="2"></td>
            <td class="listheader" width="82%">Category</td>
          </tr>
      ';
    }
    for ($i=0; $i< $len; $i++) {
      if ($this->classname == 'lightbg') {
        $this->classname = 'darkbg';
      } else {
        $this->classname = 'lightbg';
      }
      $str .='
        <tr>
          <td class="icon_'.$this->classname.'"><a href="photo.category.remove.php?ID='.$data[$i]['id'].'"><img src="images/icons/remove.gif" align="absmiddle" alt="" border="0"></a></td>
          <td class="icon_'.$this->classname.'"><a href="photo.category.edit.php?ID='.$data[$i]['id'].'"><img src="images/icons/edit.gif" align="absmiddle" alt="" border="0"></a></td>
          <td class="'.$this->classname.'">'.$data[$i]['category'].'</td>
        </tr>
      ';
    }
    return $str;
  }

  function remove($image_id) {
    $this->ImageHandler->DeleteImage($image_id);
    $this->sql->Delete("DELETE FROM ".$this->TABLES['photogallery']." WHERE image_id = $image_id");
    return true;
  }
  
  function setPreferences($per_page, $thumb_width, $max_height, $postcard_lifetime, $postcard_subject, $postcard_body, $postcard_senderemail, $site_url, $date_formatting) {
    $this->sql->Delete("DELETE FROM ".$this->TABLES['settings']."");
    $this->sql->Insert("INSERT INTO ".$this->TABLES['settings']." (date_formatting, per_page, thumb_width, max_height, postcard_lifetime, postcard_subject, postcard_body, postcard_senderemail, site_url) VALUES ('".addslashes($date_formatting)."', ".$per_page.", ".$thumb_width.", ".$max_height.", ".$postcard_lifetime.", '".addslashes($postcard_subject)."', '".addslashes($postcard_body)."', '".addslashes($postcard_senderemail)."', '".addslashes($site_url)."')");
    return true;
  }
  
  function getPreferences() {
    return $this->sql->Select("SELECT * FROM ".$this->TABLES['settings']."");
  }

  function FormatDate($format, $time) {
    if ($time == 0) {
      return 'N/A';
    }
    $year=substr($time,0,4);
    $month=substr($time,4,2);
    $day=substr($time,6,2);
    $hour=substr($time,8,2);
    $minute=substr($time,10,2);
    $seconds=substr($time,12,2);
    $month = (strlen($month) > 1) ? $month*1 : $month;
    $day = (strlen($day) > 1) ? $day*1 : $day;
    return date ($format, mktime($hour,$minute,$seconds,$month,$day,$year));
  }

  function isValidEmail($email) {
  	if (!eregi("^([a-zA-Z0-9\._\-]+)@([a-zA-Z0-9\._\-]+)\\.([a-zA-Z]+)$", $email)) {
  		$this->appendErrorMessage('Invalid email address');
  		return false;
  	} else {
  		return true;
  	}
  }

  function appendErrorMessage($msg) {
    $this->ERROR_MSG .= $msg.'<br>';
  }

  function getNumPages($num_rows) {
    if ($num_rows <= $this->PER_PAGE) {
      $num_pages = 1;  
    } else if (($num_rows % $this->PER_PAGE) == 0) {
      $num_pages = ($num_rows / $this->PER_PAGE);
    } else {  
      $num_pages = ($num_rows / $this->PER_PAGE) + 1;
    }  
    $num_pages = (int) $num_pages;
    return $num_pages;
  }
}
?>